#!/usr/bin/env python3

print('[')

for i in range(40):
    x = i * 100
    y = 100
    while x >= 1000:
        x -= 1000
        y += 100
    pos = [x + 10, y + 10]
    print(f'    {{ "type": "MouseMove", "pos": {pos} }},')
    print(f'    {{ "type": "MouseDown", "pos": {pos}, "btn": "Left" }},')
    print(f'    {{ "type": "MouseUp", "pos": {pos}, "btn": "Left" }},')

pos = [10, 10]
print(f'    {{ "type": "MouseMove", "pos": {pos} }},')
print(f'    {{ "type": "MouseDown", "pos": {pos}, "btn": "Left" }},')
print(f'    {{ "type": "MouseUp", "pos": {pos}, "btn": "Left" }},')

print(f'    {{ "type": "Wait" }}')
print(']')



from http.server import HTTPServer, BaseHTTPRequestHandler

img = None
with open("test.png", "rb") as f:
    img = f.read()

class MyHandler(BaseHTTPRequestHandler):
    def do_GET(self):
        print("GET: " + self.path + " " + str(self.headers))

        self.send_response(200)
        self.send_header("Access-Control-Allow-Origin", "*")

        resp_data = None
        if self.path == "/crossdomain.xml":
            resp_data = bytes("""
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE cross-domain-policy SYSTEM "http://www.adobe.com/xml/dtds/cross-domain-policy.dtd">
<cross-domain-policy>
  <allow-access-from domain="*" />
  <allow-http-request-headers-from domain="file://*" headers="*" secure="true"/>
</cross-domain-policy>
""", "utf-8")
            self.send_header("Content-type", "application/xml")
        else:
            resp_data = img
            self.send_header("Content-type", "image/png")

        self.end_headers()
        self.wfile.write(resp_data)

    def do_POST(self):
        print("POST: " + self.path + " " + str(self.headers))
        self.send_response(200)
        self.send_header("Content-type", "WTF-image/png")
        self.send_header("Access-Control-Allow-Origin", "*")
        self.end_headers()
        self.wfile.write(img)

def run(server_class=HTTPServer, handler_class=MyHandler):
    server_address = ('', 8000)
    httpd = server_class(server_address, handler_class)
    print("Running server")
    httpd.serve_forever()

run()



from pathlib import Path
from yaml import load, dump

featherGlyphs = Path("./featherIcons/").glob("*.svg")

glyphs=(
    *featherGlyphs,
)

yamlDump = {
    'font':{
        'ttf': 'OpenFontIcons.ttf',
        'fixedwidth': True,
        'name': 'OpenFontIcon',
    },
    'glyphs':[],
}

for glyph in glyphs:
    yamlDump['glyphs'].append({
        'glyph': str(glyph),
        'name': glyph.name[5:][:-4],
        'code': hex(int(glyph.name[:4])+57344),
        'char': chr(int(glyph.name[:4])+57344),
    })


Path('./fontManifest.yaml').write_text(dump(yamlDump, allow_unicode=True))

yamlDump = {
    'font':{
        'ttf': 'BrandFontIcons.ttf',
        'fixedwidth': True,
        'name': 'BrandFontIcon',
    },
    'glyphs':[],
}

for glyph in Path("./brands/").glob("*.svg"):
    yamlDump['glyphs'].append({
        'glyph': str(glyph),
        'name': glyph.name[8:][:-4],
        'code': hex(int(glyph.name[:7])+983040),
        'char': chr(int(glyph.name[:7])+983040),
    })


Path('./brandFontManifest.yaml').write_text(dump(yamlDump, allow_unicode=True))



#!/usr/bin/env python3

import sys
from os import path

sys.stdout.reconfigure(encoding='utf-8')

input_file = path.join(path.dirname(__file__), 'input.txt')
with open(input_file, 'r', encoding='utf-8') as file:
    characters = file.read().replace(' ', '').replace('\n', '')

print('[')
for ch in characters:
    print(f'    {{ "type": "TextInput", "codepoint": "{ch}" }},')

print(f'    {{ "type": "KeyDown", "key_code": 27 }}')

print(']')



#!/usr/bin/env python3

coord_map = {
    'void':    [1,   1],
    'sprite1': [1,   101],
    'sprite2': [101, 101],
    'sprite3': [201, 101],
}

click_seq = [
    'tab', 'tab', 'esc',
    'sprite1', 'tab', 'esc',
    'sprite2', 'tab', 'esc',
    'tab', 'sprite2', 'esc',
    'sprite3', 'tab', 'esc',
    'void', 'esc',
]

print('[')

for obj in click_seq:
    if obj == 'esc':
        print(f'    {{ "type": "KeyDown", "key_code": 27 }},')
        print(f'    {{ "type": "KeyUp", "key_code": 27 }},')
        continue
    if obj == 'tab':
        print(f'    {{ "type": "KeyDown", "key_code": 9 }},')
        print(f'    {{ "type": "KeyUp", "key_code": 9 }},')
        continue
    pos = coord_map[obj]
    print(f'    {{ "type": "MouseMove", "pos": {pos} }},')
    print(f'    {{ "type": "MouseDown", "pos": {pos}, "btn": "Left" }},')
    print(f'    {{ "type": "MouseUp", "pos": {pos}, "btn": "Left" }},')

print(f'    {{ "type": "FocusLost" }}')
print(']')



from http.server import HTTPServer, BaseHTTPRequestHandler

responses = [
    #     let packet = Packet {
    #         version: AMFVersion::AMF0,
    #         headers: vec![],
    #         messages: vec![Message{
    #             target_uri: "/1/onStatus".to_string(),
    #             response_uri: "".to_string(),
    #             contents: Rc::new(Value::String("Success!".to_string())),
    #         }],
    #     };
    [0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x0B, 0x2F, 0x31, 0x2F, 0x6F, 0x6E, 0x52, 0x65, 0x73, 0x75, 0x6C, 0x74,
     0x00, 0x00, 0x00, 0x00, 0x00, 0x0B, 0x02, 0x00, 0x08, 0x53, 0x75, 0x63, 0x63, 0x65, 0x73, 0x73, 0x21],

    #     let packet = Packet {
    #         version: AMFVersion::AMF0,
    #         headers: vec![],
    #         messages: vec![Message{
    #             target_uri: "/1/onStatus".to_string(),
    #             response_uri: "".to_string(),
    #             contents: Rc::new(Value::Number(-123.0)),
    #         }],
    #     };
    [0x00, 0x00, 0x00, 0x00, 0x00, 0x01, 0x00, 0x0B, 0x2F, 0x31, 0x2F, 0x6F, 0x6E, 0x53, 0x74, 0x61, 0x74, 0x75, 0x73,
     0x00, 0x00, 0x00, 0x00, 0x00, 0x09, 0x00, 0xC0, 0x5E, 0xC0, 0x00, 0x00, 0x00, 0x00, 0x00],

    #     let packet = Packet {
    #         version: AMFVersion::AMF0,
    #         headers: vec![Header {
    #             name: "Response Header".to_string(),
    #             must_understand: false,
    #             value: Rc::new(Value::String("Spookily ignored by flash!".to_string())),
    #         }],
    #         messages: vec![
    #             Message {
    #                 target_uri: "/1/onStatus".to_string(),
    #                 response_uri: "".to_string(),
    #                 contents: Rc::new(Value::Bool(false)),
    #             },
    #             Message {
    #                 target_uri: "/2/onResult".to_string(),
    #                 response_uri: "".to_string(),
    #                 contents: Rc::new(Value::Bool(true)),
    #             },
    #         ],
    #     };
    [0x00, 0x00, 0x00, 0x01, 0x00, 0x0F, 0x52, 0x65, 0x73, 0x70, 0x6F, 0x6E, 0x73, 0x65, 0x20, 0x48, 0x65, 0x61, 0x64,
     0x65, 0x72, 0x00, 0x00, 0x00, 0x00, 0x1D, 0x02, 0x00, 0x1A, 0x53, 0x70, 0x6F, 0x6F, 0x6B, 0x69, 0x6C, 0x79, 0x20,
     0x69, 0x67, 0x6E, 0x6F, 0x72, 0x65, 0x64, 0x20, 0x62, 0x79, 0x20, 0x66, 0x6C, 0x61, 0x73, 0x68, 0x21, 0x00, 0x02,
     0x00, 0x0B, 0x2F, 0x31, 0x2F, 0x6F, 0x6E, 0x53, 0x74, 0x61, 0x74, 0x75, 0x73, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02,
     0x01, 0x00, 0x00, 0x0B, 0x2F, 0x32, 0x2F, 0x6F, 0x6E, 0x52, 0x65, 0x73, 0x75, 0x6C, 0x74, 0x00, 0x00, 0x00, 0x00,
     0x00, 0x02, 0x01, 0x01],

    # Give a 404 error
    None,
]

class MyHandler(BaseHTTPRequestHandler):
    def do_POST(self):
        print("")
        print("Navigator::fetch:")
        print("  URL: http://localhost:8000")
        print("  Method: POST")
        print(f"  Mime-Type: {self.headers.get('Content-Type')}")

        request = self.rfile.read(int(self.headers['Content-Length']))
        request = ", ".join([f"{byte:02X}" for byte in request])

        print(f"  Body: [{request}]")
        print("")

        response = responses.pop(0)
        if response:
            self.send_response(200)
            self.end_headers()
            self.wfile.write(bytes(response))
        else:
            self.send_response(404)

def run(server_class=HTTPServer, handler_class=MyHandler):
    server_address = ('', 8000)
    httpd = server_class(server_address, handler_class)
    print("Running server")
    httpd.serve_forever()

run()



# You can use this to recreate input.json from Flash Player output if necessary.

import re

first = True
with open('output.txt', 'rt') as f:
    print('[')
    for line in f:
        if m := re.match('^_root (\d+) (\d+)', line):
            x, y = m.groups()
            if not first:
                print(',')
            print(f'  {{"type": "MouseMove", "pos": [{x}, {y}]}}, {{"type": "Wait"}}', end='')
            first = False
    print('\n]')



#!/usr/bin/env python3

key_seq = [
    'tab',
    'tab',
    'right',
    'down',
    'down',
    'left',
    'left',
    'up',
    'left',
    'down',
    'down',
    'right',
    'down',
    'esc',
]

print('[')

for obj in key_seq:
    key = None
    if obj == 'esc':
        key = 27
    elif obj == 'tab':
        key = 9
    elif obj == 'left':
        key = 37
    elif obj == 'up':
        key = 38
    elif obj == 'right':
        key = 39
    elif obj == 'down':
        key = 40
    print(f'    {{ "type": "KeyDown", "key_code": {key} }},')
    print(f'    {{ "type": "KeyUp", "key_code": {key} }},')

print(f'    {{ "type": "Wait" }}')
print(']')
